# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bixo/diva/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/bixo/diva/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Bixo\\Diva\\": "packages/bixo/diva/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bixo\Diva\Providers\DivaServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Diva'  => Bixo\Diva\Facades\Diva::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bixo\\DivaTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bixo\Diva\Providers\DivaServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bixo\Diva\Providers\DivaServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bixo\Diva\Providers\DivaServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/diva/{modulename}

**User**

    http://path-to-route-folder/user/diva/{modulename}

**Public**

    http://path-to-route-folder/divas


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/diva/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/diva/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/diva/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/diva/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/diva/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/diva/{modulename}/{slug}
    METHOD: GET